Your message dated Sun, 17 Jan 2021 20:49:28 +0000
with message-id <[email protected]>
and subject line Bug#980294: fixed in flot 4.2.1+dfsg-3
has caused the Debian Bug report #980294,
regarding libjs-jquery-flot: All chart legends come out as all black
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)


-- 
980294: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=980294
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Package: libjs-jquery-flot
Version: 4.2.1+dfsg-2
Severity: normal
Forwarded: https://github.com/flot/flot/issues/1708
Tags: patch

Dear Maintainer,

With the upgrade to 4.x, flot lost the ability to control the legenda
background. All legends come up with black text on black blackground,
and therefore are broken by default. This has been reported upstream
more than a year ago, with a patch, and is still unfixed.

The attached patch is from https://github.com/flot/flot/pull/1709, and I
confirm that it applies cleanly to the current package and fixed the
issue for me.

-- System Information:
Debian Release: bullseye/sid
  APT prefers unstable-debug
  APT policy: (500, 'unstable-debug'), (500, 'testing-debug'), (500, 
'unstable'), (500, 'testing'), (1, 'experimental-debug'), (1, 'experimental')
Architecture: amd64 (x86_64)

Kernel: Linux 5.10.0-1-amd64 (SMP w/4 CPU threads)
Locale: LANG=pt_BR.UTF-8, LC_CTYPE=pt_BR.UTF-8 (charmap=UTF-8), 
LANGUAGE=pt_BR:pt:en
Shell: /bin/sh linked to /usr/bin/dash
Init: systemd (via /run/systemd/system)
LSM: AppArmor: enabled

Versions of packages libjs-jquery-flot depends on:
ii  libjs-jquery  3.5.1+dfsg+~3.5.5-7

Versions of packages libjs-jquery-flot recommends:
ii  javascript-common  11+nmu1
ii  libjs-excanvas     0.r4~git20090427.0000000-4

Versions of packages libjs-jquery-flot suggests:
pn  libjs-jquery-flot-docs  <none>

-- no debconf information
From bc3315ba9723bcc93c95e4820537d0432b984cd6 Mon Sep 17 00:00:00 2001
From: Marcos <[email protected]>
Date: Mon, 7 Oct 2019 16:28:19 -0300
Subject: [PATCH] Make flot to control legend backgrounds using SVG fill
 property.

SVG 2.0 uses the "fill" property to control the background color of
shapes and text.

The CSS property "background-color" has no effect on the new SVG shapes spec.
---
 source/jquery.flot.legend.js | 18 +++++++++++++++++-
 1 file changed, 17 insertions(+), 1 deletion(-)

diff --git a/source/jquery.flot.legend.js b/source/jquery.flot.legend.js
index eb48ac9d..888eafb2 100644
--- a/source/jquery.flot.legend.js
+++ b/source/jquery.flot.legend.js
@@ -11,7 +11,9 @@
             container: null, // container (as jQuery object) to put legend in, null means default on top of graph
             position: 'ne', // position of default legend container within plot
             margin: 5, // distance from grid edge to default legend container within plot
-            sorted: null // default to no legend sorting
+            sorted: null, // default to no legend sorting
+            backgroundColor: null, 
+            backgroundOpacity: 0 // No background shows by default
         }
     };
 
@@ -154,6 +156,20 @@
             options.legend.container.style.width = width + 'px';
             options.legend.container.style.height = height + 'em';
         }
+
+        // ----------------------------------------------------------------------------------------
+        // Control backgroundColor
+        // ----------------------------------------------------------------------------------------
+        if(options.legend.backgroundColor){
+            $('.legendLayer rect.background').css({
+                'fill': options.legend.backgroundColor, // New SVG 2.0 spec, uses fill
+                'background': options.legend.backgroundColor, // Back compau with SVG 1.1
+            });            
+        }
+        // ----------------------------------------------------------------------------------------
+        // Control background-opacity
+        // ----------------------------------------------------------------------------------------
+        $('.legendLayer rect.background').css('opacity', options.legend.backgroundOpacity? options.legend.backgroundOpacity : 1);
     }
 
     // Generate html for a shape

Attachment: signature.asc
Description: PGP signature


--- End Message ---
--- Begin Message ---
Source: flot
Source-Version: 4.2.1+dfsg-3
Done: Xavier Guimard <[email protected]>

We believe that the bug you reported is fixed in the latest version of
flot, which is due to be installed in the Debian FTP archive.

A summary of the changes between this version and the previous one is
attached.

Thank you for reporting the bug, which will now be closed.  If you
have further comments please address them to [email protected],
and the maintainer will reopen the bug report if appropriate.

Debian distribution maintenance software
pp.
Xavier Guimard <[email protected]> (supplier of updated flot package)

(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [email protected])


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA512

Format: 1.8
Date: Sun, 17 Jan 2021 21:22:09 +0100
Source: flot
Architecture: source
Version: 4.2.1+dfsg-3
Distribution: unstable
Urgency: medium
Maintainer: Debian Javascript Maintainers 
<[email protected]>
Changed-By: Xavier Guimard <[email protected]>
Closes: 980291 980294
Changes:
 flot (4.2.1+dfsg-3) unstable; urgency=medium
 .
   * Team upload
   * Make flot to control legend backgrounds using SVG fill (Closes: #980294)
   * Provide minified files and related maps (Closes: #980291)
Checksums-Sha1: 
 b551b3ba2b1e17bc22d48860ccc1629427d01daa 2161 flot_4.2.1+dfsg-3.dsc
 a7f0227ee22b8b3db185ac9c1b71b09557bd2afb 34728 flot_4.2.1+dfsg-3.debian.tar.xz
Checksums-Sha256: 
 b7e538e67c13222407f4c980055418a7212edf690a33532cd076764f47ffe27f 2161 
flot_4.2.1+dfsg-3.dsc
 bf15aea241e4022a0b847986ac8e192a650f0c7e54ed2573969a160466ff6e82 34728 
flot_4.2.1+dfsg-3.debian.tar.xz
Files: 
 d45c5756bc3b53c6f8dc7e7cf32b1a8b 2161 javascript optional flot_4.2.1+dfsg-3.dsc
 ea18a6d8b2d49e2dc257f937a9c5bcbe 34728 javascript optional 
flot_4.2.1+dfsg-3.debian.tar.xz

-----BEGIN PGP SIGNATURE-----

iQIzBAEBCgAdFiEEAN/li4tVV3nRAF7J9tdMp8mZ7ukFAmAEnLkACgkQ9tdMp8mZ
7un0ohAAmWCWTuuDAHE1lOJPRkCuWm6NsjFhx/HT3BZzekzTNHJY26Nt0YViPzSf
v+e6+S93jbYx0phvvAfPf7LiVMwpONb8hHDx5y0qcQOHBednp5pzrnTRx6rBYX7i
mmG5n9iqhab5GoykGAWaj1BoSJIzFf69dkPTkrG4FnTNRES8ZdKm3r40MbtkndDG
qovDWdGn+faXiP5xD195VCio+QpzdqNBZFbiW+cu7voKESfaHPQetbLWWtcLy508
RLQG+lr3XnVJ16M7Pcqf1D0/PBTgtgb3eycP1P/lC7gTDxrHRmbjk4F1dkLyma/c
OBHsDyDKVt/X/vymeKsxSIUTC6sBIHl6XXWx6Bq51b9/TDJY/h8h8D4y+sBolR7y
uS8h2vYVyLmMjxPtuMtM/Bzl6hZ52gOQgXKyEMXt0/G0qAM8w+aPuLk0kVKabMVX
0UQ3zgdq30WnvmZFa8l/BfqauRXnxh0Ihh27tFn78E0m+jh9Y9BkRE2z+PZV0PsA
3Ro7SVyTIh0PvwBuDQ3EVJ1IK0XMQO/506JsTdAoSu4CHcuEuQjA6pImly7HE/9I
tm+WVbQ8RJYxkPXhDxcrRF/8XSaGmLOo6OlR/RrF4mRxEt0EHSa9fuZZSG61RSyB
sTq8RmiwFndo93elel+u63Q5BFFRfnwf8eXSrIzObD4JvflVb24=
=rOWo
-----END PGP SIGNATURE-----

--- End Message ---
-- 
Pkg-javascript-devel mailing list
[email protected]
https://alioth-lists.debian.net/cgi-bin/mailman/listinfo/pkg-javascript-devel

Reply via email to